#include "application.hpp"
#include "slider_dialog.hpp"
#include <unistd.h>
#include <stdexcept>

void usage()
{
	QTextStream qout(stdout);
	qout << "Usage: qslider [OPTION]..." << endl
	     << "Universal slider, based on QasTools" << endl
	     << endl
	     << "OPTIONS" << endl;

	QMap <QString, QString> options;
	options["h      "] = "display this help and exit";
	options["i ICON "] = "set icon to ICON";
	options["m VALUE"] = "set maximum value to VALUE (default is 100)";
	options["s VALUE"] = "set value to VALUE (default is 0)";
	options["t SECONDS"] = "exit after SECONDS seconds";
	options["x X      "] = "set x coordinate to X (default is 0)";
	options["y y      "] = "set y coordinate to Y (default is 0)";

	foreach(QString k, options.keys()) {
		qout << "\t-" << k << "\t\t" << options[k] << endl;
	};
}


QMap <QString, QString> parse_arguments(int argc, char *argv[])
{
	QMap <QString, QString> options;
	int c;
	while ((c = getopt(argc, argv, "i:m:s:t:x:y:h")) != -1) {
		switch (c) {
		case 'h':
			options.insert("help", QString());
			break;
		case 'i':
                        options.insert("icon", QString::fromLocal8Bit(optarg));
			break;
		case 'm':
                        options.insert("max", QString::fromLocal8Bit(optarg));
			break;
		case 's':
                        options.insert("current", QString::fromLocal8Bit(optarg));
			break;
		case 't':
                        options.insert("timer", QString::fromLocal8Bit(optarg));
			break;
		case 'x':
                        options.insert("x", QString::fromLocal8Bit(optarg));
			break;
		case 'y':
                        options.insert("y", QString::fromLocal8Bit(optarg));
			break;
		case '?':
			throw std::invalid_argument("");
		default:
			throw std::invalid_argument("");
		}
	}
	return options;
}

int main(int argc, char *argv[])
{
    Qas_Application app("qslider" + QString::fromLocal8Bit(getenv("DISPLAY")),
                        argc, argv);
	QMap<QString, QString> options;

	try {
		options = parse_arguments(argc, argv);
	} catch (std::invalid_argument) {
		return 1;
	}
	if (options.contains("help")) {
		usage();
		return 0;
	}
    Slider_Dialog *sd = new Slider_Dialog(options);
    sd->show();
	return app.exec();
}
